# Generated by Django 3.2.17 on 2023-04-05 18:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0052_convert_last_action_date_to_datefield'),
    ]

    operations = [
        migrations.AddField(
            model_name='person',
            name='councilmatic_biography',
            field=models.TextField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.9 on 2019-06-11 21:34

import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("legislative", "0008_longer_event_name"),
        ("councilmatic_core", "0045_auto_20190513_1250"),
    ]

    operations = [
        migrations.CreateModel(
            name="BillDocument",
            fields=[
                (
                    "document",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="councilmatic_document",
                        serialize=False,
                        to="legislative.BillDocument",
                    ),
                ),
                ("full_text", models.TextField(blank=True, null=True)),
            ],
            options={
                "abstract": False,
            },
            bases=("legislative.billdocument",),
        ),
        migrations.AlterField(
            model_name="person",
            name="headshot",
            field=models.FileField(
                default="images/headshot_placeholder.png",
                storage=django.core.files.storage.FileSystemStorage(
                    base_url="/",
                    location="/Users/hannah/projects/chi-councilmatic/chicago/static",
                ),
                upload_to="images",
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Action",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("date", models.DateTimeField(default=None)),
                ("classification", models.CharField(max_length=100)),
                ("description", models.TextField(blank=True)),
                ("order", models.IntegerField()),
            ],
        ),
        migrations.CreateModel(
            name="ActionRelatedEntity",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("entity_type", models.CharField(max_length=100)),
                ("entity_name", models.CharField(max_length=255)),
                ("organization_ocd_id", models.CharField(max_length=100, blank=True)),
                ("person_ocd_id", models.CharField(max_length=100, blank=True)),
                (
                    "action",
                    models.ForeignKey(
                        related_name="related_entities",
                        to="councilmatic_core.Action",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="AgendaItemBill",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("note", models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name="Bill",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("ocd_id", models.CharField(max_length=100, unique=True)),
                ("description", models.TextField()),
                ("identifier", models.CharField(max_length=50)),
                ("bill_type", models.CharField(max_length=50)),
                ("classification", models.CharField(max_length=100)),
                ("date_created", models.DateTimeField(default=None)),
                ("date_updated", models.DateTimeField(null=True, default=None)),
                ("source_url", models.CharField(max_length=255)),
                ("source_note", models.CharField(max_length=255, blank=True)),
                ("full_text", models.TextField(blank=True)),
                ("abstract", models.TextField(blank=True)),
                ("last_action_date", models.DateTimeField(null=True, default=None)),
                ("slug", models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="BillDocument",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                (
                    "bill",
                    models.ForeignKey(
                        related_name="documents",
                        to="councilmatic_core.Bill",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Document",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("note", models.TextField()),
                ("url", models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name="Event",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("ocd_id", models.CharField(max_length=100, unique=True)),
                ("name", models.CharField(max_length=255)),
                ("description", models.TextField()),
                ("classification", models.CharField(max_length=100)),
                ("start_time", models.DateTimeField()),
                ("end_time", models.DateTimeField(null=True)),
                ("all_day", models.BooleanField(default=False)),
                ("status", models.CharField(max_length=100)),
                ("location_name", models.CharField(max_length=255)),
                ("location_url", models.CharField(max_length=255, blank=True)),
                ("source_url", models.CharField(max_length=255)),
                ("source_note", models.CharField(max_length=255, blank=True)),
                ("slug", models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="EventAgendaItem",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("order", models.IntegerField()),
                ("description", models.TextField()),
                (
                    "event",
                    models.ForeignKey(
                        related_name="agenda_items",
                        to="councilmatic_core.Event",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="EventDocument",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                (
                    "document",
                    models.ForeignKey(
                        related_name="events",
                        to="councilmatic_core.Document",
                        on_delete=models.CASCADE,
                    ),
                ),
                (
                    "event",
                    models.ForeignKey(
                        related_name="documents",
                        to="councilmatic_core.Event",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="EventParticipant",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("note", models.TextField()),
                ("entity_name", models.CharField(max_length=255)),
                ("entity_type", models.CharField(max_length=100)),
                (
                    "event",
                    models.ForeignKey(
                        related_name="participants",
                        to="councilmatic_core.Event",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="LegislativeSession",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("identifier", models.CharField(max_length=255)),
                ("jurisdiction_ocd_id", models.CharField(max_length=255)),
                ("name", models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name="Membership",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("label", models.CharField(max_length=255, blank=True)),
                ("role", models.CharField(max_length=255, blank=True)),
                ("start_date", models.DateField(null=True, default=None)),
                ("end_date", models.DateField(null=True, default=None)),
            ],
        ),
        migrations.CreateModel(
            name="Organization",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("ocd_id", models.CharField(max_length=100, unique=True)),
                ("name", models.CharField(max_length=255)),
                ("classification", models.CharField(max_length=255, null=True)),
                ("source_url", models.CharField(max_length=255, blank=True)),
                ("slug", models.CharField(max_length=255, unique=True)),
                (
                    "parent",
                    models.ForeignKey(
                        null=True,
                        to="councilmatic_core.Organization",
                        related_name="children",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Person",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("ocd_id", models.CharField(max_length=100, unique=True)),
                ("name", models.CharField(max_length=100)),
                ("headshot", models.CharField(max_length=255, blank=True)),
                ("source_url", models.CharField(max_length=255)),
                ("source_note", models.CharField(max_length=255, blank=True)),
                ("website_url", models.CharField(max_length=255, blank=True)),
                ("email", models.CharField(max_length=255, blank=True)),
                ("slug", models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="Post",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("ocd_id", models.CharField(max_length=100, unique=True)),
                ("label", models.CharField(max_length=255)),
                ("role", models.CharField(max_length=255)),
                (
                    "organization",
                    models.ForeignKey(
                        related_name="posts",
                        to="councilmatic_core.Organization",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Sponsorship",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        verbose_name="ID",
                        serialize=False,
                    ),
                ),
                ("classification", models.CharField(max_length=255)),
                ("is_primary", models.BooleanField(default=False)),
                (
                    "bill",
                    models.ForeignKey(
                        related_name="sponsorships",
                        to="councilmatic_core.Bill",
                        on_delete=models.CASCADE,
                    ),
                ),
                (
                    "person",
                    models.ForeignKey(
                        related_name="sponsorships",
                        to="councilmatic_core.Person",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="membership",
            name="organization",
            field=models.ForeignKey(
                related_name="memberships",
                to="councilmatic_core.Organization",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="membership",
            name="person",
            field=models.ForeignKey(
                related_name="memberships",
                to="councilmatic_core.Person",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="membership",
            name="post",
            field=models.ForeignKey(
                null=True,
                to="councilmatic_core.Post",
                related_name="memberships",
                on_delete=models.SET_NULL,
            ),
        ),
        migrations.AddField(
            model_name="billdocument",
            name="document",
            field=models.ForeignKey(
                related_name="bills",
                to="councilmatic_core.Document",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="bill",
            name="from_organization",
            field=models.ForeignKey(
                null=True,
                to="councilmatic_core.Organization",
                related_name="bills",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="bill",
            name="legislative_session",
            field=models.ForeignKey(
                null=True,
                to="councilmatic_core.LegislativeSession",
                related_name="bills",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="agendaitembill",
            name="agenda_item",
            field=models.ForeignKey(
                related_name="related_bills",
                to="councilmatic_core.EventAgendaItem",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="agendaitembill",
            name="bill",
            field=models.ForeignKey(
                related_name="related_agenda_items",
                to="councilmatic_core.Bill",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="action",
            name="bill",
            field=models.ForeignKey(
                null=True,
                to="councilmatic_core.Bill",
                related_name="actions",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="action",
            name="organization",
            field=models.ForeignKey(
                null=True,
                to="councilmatic_core.Organization",
                related_name="actions",
                on_delete=models.CASCADE,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0001_initial"),
    ]

    operations = [
        migrations.RenameField(
            model_name="bill",
            old_name="date_created",
            new_name="ocd_created_at",
        ),
        migrations.RenameField(
            model_name="bill",
            old_name="date_updated",
            new_name="ocd_updated_at",
        ),
        migrations.RemoveField(
            model_name="action",
            name="bill",
        ),
        migrations.RemoveField(
            model_name="action",
            name="organization",
        ),
        migrations.RemoveField(
            model_name="actionrelatedentity",
            name="action",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="from_organization",
        ),
        migrations.RemoveField(
            model_name="bill",
            name="legislative_session",
        ),
        migrations.RemoveField(
            model_name="membership",
            name="organization",
        ),
        migrations.RemoveField(
            model_name="membership",
            name="person",
        ),
        migrations.RemoveField(
            model_name="membership",
            name="post",
        ),
        migrations.RemoveField(
            model_name="organization",
            name="parent",
        ),
        migrations.RemoveField(
            model_name="post",
            name="organization",
        ),
        migrations.RemoveField(
            model_name="sponsorship",
            name="bill",
        ),
        migrations.RemoveField(
            model_name="sponsorship",
            name="person",
        ),
        migrations.AddField(
            model_name="action",
            name="_bill",
            field=models.ForeignKey(
                null=True,
                related_name="actions",
                db_column="bill_id",
                to="councilmatic_core.Bill",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="action",
            name="_organization",
            field=models.ForeignKey(
                null=True,
                related_name="actions",
                db_column="organization_id",
                to="councilmatic_core.Organization",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="actionrelatedentity",
            name="_action",
            field=models.ForeignKey(
                null=True,
                related_name="related_entities",
                db_column="action_id",
                to="councilmatic_core.Action",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="bill",
            name="_from_organization",
            field=models.ForeignKey(
                null=True,
                related_name="bills",
                db_column="from_organization_id",
                to="councilmatic_core.Organization",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="bill",
            name="_legislative_session",
            field=models.ForeignKey(
                null=True,
                related_name="bills",
                db_column="legislative_session_id",
                to="councilmatic_core.LegislativeSession",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="event",
            name="ocd_created_at",
            field=models.DateTimeField(default=None),
        ),
        migrations.AddField(
            model_name="event",
            name="ocd_updated_at",
            field=models.DateTimeField(default=None),
        ),
        migrations.AddField(
            model_name="membership",
            name="_organization",
            field=models.ForeignKey(
                null=True,
                related_name="memberships",
                db_column="organization_id",
                to="councilmatic_core.Organization",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="membership",
            name="_person",
            field=models.ForeignKey(
                null=True,
                related_name="memberships",
                db_column="person_id",
                to="councilmatic_core.Person",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="membership",
            name="_post",
            field=models.ForeignKey(
                null=True,
                related_name="memberships",
                db_column="post_id",
                to="councilmatic_core.Post",
                on_delete=models.SET_NULL,
            ),
        ),
        migrations.AddField(
            model_name="organization",
            name="_parent",
            field=models.ForeignKey(
                null=True,
                related_name="children",
                db_column="parent_id",
                to="councilmatic_core.Organization",
                on_delete=models.SET_NULL,
            ),
        ),
        migrations.AddField(
            model_name="post",
            name="_organization",
            field=models.ForeignKey(
                null=True,
                related_name="posts",
                db_column="organization_id",
                to="councilmatic_core.Organization",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="sponsorship",
            name="_bill",
            field=models.ForeignKey(
                null=True,
                related_name="sponsorships",
                db_column="bill_id",
                to="councilmatic_core.Bill",
                on_delete=models.CASCADE,
            ),
        ),
        migrations.AddField(
            model_name="sponsorship",
            name="_person",
            field=models.ForeignKey(
                null=True,
                related_name="sponsorships",
                db_column="person_id",
                to="councilmatic_core.Person",
                on_delete=models.CASCADE,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-06-27 19:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0041_event_extras"),
    ]

    operations = [
        migrations.AddField(
            model_name="eventagendaitem",
            name="plain_text",
            field=models.TextField(null=True),
        ),
    ]



import os

from django.core.management import call_command
from django.core.management.base import BaseCommand
from django.db import connection


class Command(BaseCommand):
    help = "Refresh the test fixtures from an instance database"

    def _id_gen(self, table):
        with connection.cursor() as cursor:
            cursor.execute("SELECT id FROM opencivicdata_{} LIMIT 3".format(table))
            ids = [row[0] for row in cursor]
        return ids

    def handle(self, *args, **options):
        current_directory = os.path.dirname(__file__)

        outfiles = []

        for table in ("bill", "person", "organization", "event"):
            args = (
                ["dump_object", "councilmatic_core.{}".format(table.title())]
                + self._id_gen(table)
                + ["--kitchensink"]
            )
            outfile = os.path.join(
                current_directory, "..", "..", "..", "{}.json".format(table)
            )
            self.stdout.write("writing {}".format(outfile))
            with open(outfile, "w") as f:
                call_command(*args, stdout=f)
            outfiles.append(outfile)

        self.stdout.write("merging outfiles")

        with open(
            os.path.join(
                current_directory,
                "..",
                "..",
                "..",
                "tests",
                "fixtures",
                "test_data.json",
            ),
            "w",
        ) as f:
            call_command("merge_fixtures", *outfiles, stdout=f)

        for f in outfiles:
            self.stdout.write("removing {}".format(f))
            os.remove(f)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-09-14 20:43
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0032_auto_20170912_1301"),
    ]

    operations = [
        migrations.CreateModel(
            name="RelatedBill",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("related_bill_identifier", models.CharField(max_length=100)),
                (
                    "central_bill",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="related_bills",
                        to="councilmatic_core.Bill",
                    ),
                ),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0004_auto_20151214_1413"),
    ]

    operations = [
        migrations.AddField(
            model_name="billdocument",
            name="document_type",
            field=models.CharField(
                max_length=255,
                choices=[("A", "Attachment"), ("V", "Version")],
                default="A",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="document",
            name="full_text",
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name="document",
            name="url",
            field=models.TextField(blank=True),
        ),
    ]



from django.core.management import call_command
from django.core.management.base import BaseCommand
from django.core.files import File

from opencivicdata.core.models import Person as OCDPerson

import requests


class Command(BaseCommand):
    help = "Attach headshots to councilmembers"

    def handle(self, *args, **opetions):
        for person in OCDPerson.objects.exclude(image=""):
            councilmatic_person = person.councilmatic_person
            filename = councilmatic_person.slug + ".jpg"
            response = requests.get(person.image)

            self.stdout.write("Downloading {}".format(person.image))

            with open("/tmp/" + filename, "wb") as f:
                f.write(response.content)

            with open("/tmp/" + filename, "rb") as f:
                django_file = File(f)
                councilmatic_person.headshot.save(filename, django_file)

        self.stdout.write("Collecting static")

        call_command("collectstatic", verbosity=0, interactive=False)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0002_auto_20151210_1342"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bill",
            name="ocd_updated_at",
            field=models.DateTimeField(default=None),
        ),
        migrations.AlterField(
            model_name="person",
            name="ocd_id",
            field=models.CharField(unique=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name="person",
            name="slug",
            field=models.CharField(unique=True, max_length=255, null=True),
        ),
    ]



from django import template
from django.template.defaultfilters import stringfilter
from django.utils.html import strip_tags
import re

from urllib.parse import urlsplit, parse_qs, urlencode

register = template.Library()


@register.filter
@stringfilter
def sentence_case(value):
    return value.replace("_", " ").capitalize()


@register.filter
@stringfilter
def inferred_status_label(status):
    return "<span class='label label-" + status.lower() + "'>" + status + "</span>"


@register.filter
@stringfilter
def facet_name(value):
    if value == "bill_type":
        return "Legislation type"
    if value == "sponsorships":
        return "Sponsor"
    if value == "controlling_body":
        return "Controlling body"
    if value == "inferred_status":
        return "Legislation status"


@register.filter
@stringfilter
def remove_action_subj(bill_action_desc):
    # removes 'by X' from bill action descriptions & expands abbrevs
    # for more readable action labels
    clean_action = re.sub(r"\bComm\b", "Committee", bill_action_desc)
    clean_action = re.sub(r"\bRecved\b", "Received", clean_action)
    clean_action = re.sub(r"[,\s]*by\s[^\s]*", "", clean_action)

    # shorten the really long action descriptions for approval w/ modifications
    if "approved with modifications" in clean_action.lower():
        clean_action = "Approved with Modifications"

    return clean_action


@register.filter
@stringfilter
def short_blurb(text_blob):
    if len(text_blob) > 196:
        blurb = text_blob[:196]
        blurb = blurb[: blurb.rfind(" ")] + " ..."
        return blurb
    else:
        return text_blob


@register.filter
@stringfilter
def short_title(text_blob):
    if len(text_blob) > 28:
        blurb = text_blob[:24]
        blurb = blurb[: blurb.rfind(" ")] + " ..."
        return blurb
    else:
        return text_blob


@register.filter
@stringfilter
def strip_mailto(email):
    return re.sub("mailto:", "", email)


@register.filter
@stringfilter
def committee_topic_only(committee_name):
    clean = re.sub("Committee on ", "", committee_name)
    clean = re.sub("Subcommittee on ", "", clean)
    if "Mental Health, Developmental Disability" in clean:
        clean = "Mental Health & Disability"
    return clean


@register.filter
@stringfilter
def clean_html(text):
    value = strip_tags(text).replace("\n", "")
    return re.sub(r"&(?:\w+|#\d+);", "", value)


@register.filter
@stringfilter
def alternative_identifiers(id_original):
    id_1 = re.sub(" ", " 0", id_original)
    id_2 = re.sub(" ", "", id_original)
    id_3 = re.sub(" ", "", id_1)
    return " ".join(i for i in set([id_original, id_1, id_2, id_3]))


@register.filter
def get_item(dictionary, key):
    return dictionary.get(key)


@register.filter
def format_date_sort(s, fmt="%Y%m%d%H%M"):
    if s:
        return s.strftime(fmt)
    else:
        return "0"


@register.simple_tag
def search_with_querystring(request, **kwargs):
    query = urlsplit(request.get_full_path()).query
    query_as_dict = parse_qs(query)
    query_as_dict.update(kwargs)

    return "/search?" + urlencode(query_as_dict, doseq=True)


@register.simple_tag
def sort_direction(request):
    query_dict = request.GET
    return query_dict.get("order_by")


@register.filter
def reverse_sort(sort_direction):
    if sort_direction == "asc":
        return "desc"
    if sort_direction == "desc":
        return "asc"


@register.filter
def create_facet_string(selected_facets, query=None):
    facet_string = "/search/rss/?"

    if query:
        facet_string = "/search/rss/?q=" + query

    for key, values in selected_facets:
        for value in values:
            facet_string += "&selected_facets=" + key + ":" + value

    return facet_string


@register.filter
def remove_question(text):
    return text.rstrip("?")



import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), "README.rst")) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name="django-councilmatic",
    python_requires=">=3.6",
    version="3.2",
    packages=find_packages(exclude=("tests",)),
    include_package_data=True,
    license="MIT License",  # example license
    description="Core functions for councilmatic.org family",
    long_description=README,
    url="http://councilmatic.org/",
    author="DataMade, LLC",
    author_email="info@datamade.us",
    install_requires=[
        "requests>=2.20",
        "opencivicdata>=3.1.0",
        "pytz>=2015.4",
        "django-haystack>=3.2,<3.3",
        "Django>=3.2,<3.3",
        "django-proxy-overrides>=0.2.1",
        "python-dateutil>=2.7,<2.8",
        "psycopg2-binary>=2.9.5",
        "django-adv-cache-tag==1.1.2",
        "boto==2.38.0",
        "tqdm",
    ],
    extras_require={"convert_docs": ["textract"]},
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",  # example license
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-03-02 17:47
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("councilmatic_core", "0035_bill_html_text"),
    ]

    operations = [
        migrations.CreateModel(
            name="Jurisdiction",
            fields=[
                (
                    "ocd_id",
                    models.CharField(
                        max_length=100, primary_key=True, serialize=False, unique=True
                    ),
                ),
                ("name", models.CharField(max_length=300)),
                ("classification", models.CharField(max_length=50)),
                ("url", models.CharField(max_length=2000)),
            ],
        ),
        migrations.AddField(
            model_name="organization",
            name="jurisdiction",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="organizations",
                to="councilmatic_core.Jurisdiction",
            ),
        ),
    ]
